==> transito-0.8.2.tar.gz: transito-v0.8.2/src/uipages/pageload/pageload.go <==
package pageload

import (
	"fmt"
	"time"

	"gioui.org/font"
	"gioui.org/font/gofont"
	"gioui.org/layout"
	"gioui.org/text"
	"gioui.org/unit"
	"gioui.org/widget"
	"gioui.org/widget/material"
	"git.sr.ht/~mil/transito/src/components/styledbutton"
	"git.sr.ht/~mil/transito/src/globalstate"
)

type PageLoad struct {
	GlobalState          *globalstate.GlobalState
	list                 widget.List
	showLog              bool
	clickableShowHideLog widget.Clickable
}

func Initialize(u *globalstate.GlobalState) *PageLoad {
	page := PageLoad{
		GlobalState: u,
		list:        widget.List{List: layout.List{Axis: layout.Vertical}},
	}
	page.GlobalState.Theme.Shaper = text.NewShaper(text.WithCollection(gofont.Collection()))
	return &page
}

func (page *PageLoad) Render(gtx layout.Context) layout.Dimensions {
	var widgetsScroll = []layout.Widget{}

	widgetsScroll = append(widgetsScroll, func(gtx layout.Context) layout.Dimensions {
		var (
			pad         = unit.Dp(2)
			textLine    = material.Body1(page.GlobalState.Theme, page.GlobalState.PendingLoadInfo.Message)
			subtextLine = material.Body2(page.GlobalState.Theme, page.GlobalState.PendingLoadInfo.SubMessage)
		)
		textLine.Font.Weight = font.Bold
		subtextLine.Font.Style = font.Italic

		return layout.Flex{Axis: layout.Vertical}.Layout(
			gtx,
			layout.Rigid(func(gtx layout.Context) layout.Dimensions {
				inset := layout.Inset{Top: pad, Bottom: pad}
				return inset.Layout(gtx, func(gtx layout.Context) layout.Dimensions {
					return textLine.Layout(gtx)
				})
			}),
			layout.Rigid(func(gtx layout.Context) layout.Dimensions {
				inset := layout.Inset{Top: 0, Bottom: 0}
				return inset.Layout(gtx, func(gtx layout.Context) layout.Dimensions {
					return subtextLine.Layout(gtx)
				})
			}),
		)
	})

	if !page.GlobalState.PendingLoadInfo.IsError {
		diff := time.Now().Sub(*page.GlobalState.PendingLoadInfo.TimerStart).Seconds()
		progressText := material.Body2(page.GlobalState.Theme, fmt.Sprintf("Progress: %.1fs ", diff))
		progressText.Font.Style = font.Italic
		widgetsScroll = append(widgetsScroll, progressText.Layout)
	}

	showHideLogButton := styledbutton.StyledButtonSmall(
		gtx, *page.GlobalState.Theme, &page.clickableShowHideLog,
		fif(page.showLog, "Hide Log", "Show Log"),
	)

	if page.clickableShowHideLog.Clicked(gtx) {
		page.showLog = !page.showLog
	}
	widgetsScroll = append(widgetsScroll, showHideLogButton)

	if page.showLog {
		logText := material.Body2(page.GlobalState.Theme, page.GlobalState.MobrouteLog.String())
		logText.Font.Style = font.Italic
		widgetsScroll = append(widgetsScroll, logText.Layout)
	}

	return material.List(page.GlobalState.Theme, &page.list).Layout(
		gtx,
		len(widgetsScroll),
		func(gtx layout.Context, i int) layout.Dimensions {
			return layout.UniformInset(unit.Dp(17)).Layout(gtx, widgetsScroll[i])
		},
	)
}

func fif[T any](b bool, ifTrue, ifFalse T) T {
	if b {
		return ifTrue
	} else {
		return ifFalse
	}
}

==> transito-0.9.1.tar.gz: transito-v0.9.1/src/uipages/pageload/pageload.go <==
package pageload

import (
	"fmt"
	"time"

	"gioui.org/font"
	"gioui.org/font/gofont"
	"gioui.org/layout"
	"gioui.org/text"
	"gioui.org/unit"
	"gioui.org/widget"
	"gioui.org/widget/material"
	"git.sr.ht/~mil/transito/src/components/styledbutton"
	"git.sr.ht/~mil/transito/src/globalstate"
)

type PageLoad struct {
	GlobalState          *globalstate.GlobalState
	list                 widget.List
	showLog              bool
	clickableShowHideLog widget.Clickable
}

func Initialize(u *globalstate.GlobalState) *PageLoad {
	page := PageLoad{
		GlobalState: u,
		list:        widget.List{List: layout.List{Axis: layout.Vertical}},
	}
	page.GlobalState.Theme.Shaper = text.NewShaper(text.WithCollection(gofont.Collection()))
	return &page
}

func (page *PageLoad) Render(gtx layout.Context) layout.Dimensions {
	var widgetsScroll = []layout.Widget{}

	widgetsScroll = append(widgetsScroll, func(gtx layout.Context) layout.Dimensions {
		var (
			pad         = unit.Dp(2)
			textLine    = material.Body1(page.GlobalState.Theme, page.GlobalState.PendingLoadInfo.Message)
			subtextLine = material.Body2(page.GlobalState.Theme, page.GlobalState.PendingLoadInfo.SubMessage)
		)
		textLine.Font.Weight = font.Bold
		subtextLine.Font.Style = font.Italic

		return layout.Flex{Axis: layout.Vertical}.Layout(
			gtx,
			layout.Rigid(func(gtx layout.Context) layout.Dimensions {
				inset := layout.Inset{Top: pad, Bottom: pad}
				return inset.Layout(gtx, func(gtx layout.Context) layout.Dimensions {
					return textLine.Layout(gtx)
				})
			}),
			layout.Rigid(func(gtx layout.Context) layout.Dimensions {
				inset := layout.Inset{Top: 0, Bottom: 0}
				return inset.Layout(gtx, func(gtx layout.Context) layout.Dimensions {
					return subtextLine.Layout(gtx)
				})
			}),
		)
	})

	if !page.GlobalState.PendingLoadInfo.IsError {
		diff := time.Since(*page.GlobalState.PendingLoadInfo.TimerStart).Seconds()
		progressText := material.Body2(page.GlobalState.Theme, fmt.Sprintf("Progress: %.1fs ", diff))
		progressText.Font.Style = font.Italic
		widgetsScroll = append(widgetsScroll, progressText.Layout)
	}

	showHideLogButton := styledbutton.StyledButtonSmall(
		gtx, *page.GlobalState.Theme, &page.clickableShowHideLog,
		fif(page.showLog, "Hide Log", "Show Log"),
	)

	if page.clickableShowHideLog.Clicked(gtx) {
		page.showLog = !page.showLog
	}
	widgetsScroll = append(widgetsScroll, showHideLogButton)

	if page.showLog {
		logText := material.Body2(page.GlobalState.Theme, page.GlobalState.MobrouteLog.String())
		logText.Font.Style = font.Italic
		widgetsScroll = append(widgetsScroll, logText.Layout)
	}

	return material.List(page.GlobalState.Theme, &page.list).Layout(
		gtx,
		len(widgetsScroll),
		func(gtx layout.Context, i int) layout.Dimensions {
			return layout.UniformInset(unit.Dp(17)).Layout(gtx, widgetsScroll[i])
		},
	)
}

func fif[T any](b bool, ifTrue, ifFalse T) T {
	if b {
		return ifTrue
	} else {
		return ifFalse
	}
}
